/******************************************************************************
  defs.h -- Ubiquitous defines for ELS
  
  Author: Mark Baranowski (markb@elen.utah.edu)

  Last significant change: May 23, 2000
  
  These functions are provided "as is" in the hopes that they might serve some
  higher purpose.  If you want these functions to serve some lower purpose,
  then that too is all right.  So as to keep these hopes alive you may
  freely distribute these functions so long as this header remains intact.
  You may also freely distribute modified versions of these functions so long
  as you indicate that such versions are modified and so long as you
  provide access to the unmodified original copy.
  
  Note: The most recent version of these functions may be obtained from
  ftp://auriga.elen.utah.edu/pub/markb/els.tar.Z

  ****************************************************************************/

#ifndef ELS__DEFS_H
#define ELS__DEFS_H

#define Void	(void)	/* void type-cast sans parentheses */
#define Local	static	/* synonym for static storage-class */
#define Global	extern	/* synonym for extern storage-class */
#define Fast  register	/* synonym for register storage-class */
#define Hw    volatile	/* type-qualifier used for all hardware addresses */

typedef char		Boole;	/* TRUE or FALSE variable or function */
typedef char		(*Boole_Function)();
typedef	unsigned char	Uchar;
typedef	unsigned short	Ushort;
typedef	unsigned int	Uint;
typedef	unsigned long	Ulong;
typedef	unsigned long	Paddr;	/* Physical address in its non-pointer form */

#ifdef __cplusplus
typedef int		(*Int_Function)(void);
typedef void		(*Void_Function)(void);
#else
typedef int		(*Int_Function)();
typedef void		(*Void_Function)();
#endif

#undef   NULL
#define  NULL	0
#define  CNULL	'\0'
#undef   TRUE
#define  TRUE	(Boole)1
#undef   FALSE
#define  FALSE	(Boole)0

#define  SECS_PER_MIN   ((Ulong)60)
#define  SECS_PER_HOUR  (60 * SECS_PER_MIN)
#define  SECS_PER_DAY   (24 * SECS_PER_HOUR)
#define  SECS_PER_WEEK  (7 * SECS_PER_DAY)
#define  SECS_PER_YEAR  (365 * SECS_PER_DAY + SECS_PER_DAY / 4) /* Average */
#define  SECS_PER_MONTH (SECS_PER_YEAR / 12)			/* Average */

#define  IS_MEMBER(c,s)     ((c) != CNULL && strchr(s,c) != NULL)
#define  IS_NOT_MEMBER(c,s) ((c) == CNULL || strchr(s,c) == NULL)

/* Set one or more bits: */
#define  SETBITS(x,bits)  x |= (bits)
#define  SETBIT(x,bit)    SETBITS(x,bit)
/* Clear one or more bits: */
#define  CLRBITS(x,bits)  x &= ~(bits)
#define  CLRBIT(x,bit)    CLRBITS(x,bit)
/* Test for ALL bits being set: */
#define  ALLBITS(x,bits)  (((x) & (bits)) == (bits))
/* Test for ANY bit being set: */
#define  ANYBIT(x,bit)    (((x) & (bit)) != 0)

/*---------------------------------------------------------------------------*/
#ifdef HAVE_STAT64
#define stat  stat64
#define lstat lstat64
#else
#undef  stat
#undef  lstat
#endif
/*---------------------------------------------------------------------------*/
/* blkcnt_t is inconstantly defined; however, the following assumption
   should work for all cases dealing with st_block calculations in both
   the stat32 and stat64 environments: */
#if defined(HAVE_STAT64)
#define BLKCNT_T   long long
#else
#define BLKCNT_T   long 
#endif
/*---------------------------------------------------------------------------*/

#endif /*ELS__DEFS_H*/
