/******************************************************************************
  els.c -- els functions and defines
  
  Author: Mark Baranowski (markb@elen.utah.edu)

  Last significant change: August 9, 2000
  
  These functions are provided "as is" in the hopes that they might serve some
  higher purpose.  If you want these functions to serve some lower purpose,
  then that too is all right.  So as to keep these hopes alive you may
  freely distribute these functions so long as this header remains intact.
  You may also freely distribute modified versions of these functions so long
  as you indicate that such versions are modified and so long as you
  provide access to the unmodified original copy.
  
  Note: The most recent version of these functions may be obtained from
  ftp://auriga.elen.utah.edu/pub/markb/els.tar.Z

  ****************************************************************************/

#ifndef ELS__ELS_H
#define ELS__ELS_H

/* Determine maximum size of file name and path name based on information
   found in /usr/include/dirent.h and /usr/include/sys/param.h: */

#include <dirent.h>
#include <sys/param.h>

#if defined(MAXNAMLEN)
#  define MAX_FNAME MAXNAMLEN	/* SunOS4&5, Ultrix, ICS */
#elif defined(_MAXNAMLEN)
#  define MAX_FNAME _MAXNAMLEN	/* HPUX */
#elif defined(NAME_MAX)
#  define MAX_FNAME NAME_MAX	/* Linux2 */
#else
#  define MAX_FNAME 255		/* Default: AIX */
#endif

/* Maximum size of directory name: */
#if defined(MAXPATHLEN)
#  define MAX_DNAME MAXPATHLEN	/* SunOS4&5, Ultrix, HPUX */
#elif defined(_D_NAME_MAX)
#  define MAX_DNAME _D_NAME_MAX	/* AIX */
#elif defined(PATH_MAX)
#  define MAX_DNAME PATH_MAX	/* Linux2 */
#else
#  define MAX_DNAME 511		/* Default: ICS */
#endif

/* Maximum size of full name (+4 for quotes, +1 for CNULL): */
#define  MAX_FULL_NAME  (MAX_DNAME+MAX_FNAME+4+1)

/* Maximum amount of info (besides the full file name) per line: */
#define  MAX_INFO  128

/* Maximum amount of output generated per line (sizeof(info) +
   sizeof(file name) + sizeof(optional symlink name) + sizeof(" -> ")): */
#define  MAX_OUTPUT  (MAX_INFO+2*MAX_FULL_NAME+4)

/* Maximum amount of output generated by a message: */
#define  MAX_MSG  (MAX_INFO+MAX_FULL_NAME)

/* Manually define maximum User/Group name to some reasonalbe length.
   I've yet to find these in any include file although at least one OS
   (i.e. SunOS4.x) allows more than 70 chars!?: */
#define  MAX_USER_GROUP_NAME  32


typedef struct Dir_Item
{
  char *mem;
  char *fname;

  Boole islink;
  Boole isdir;
  Boole isdev;

  Boole dotdir;
  Boole hidden;
  Boole listable;
  Boole searchable;

  int readdir_errno;		/* errno value set by readdir() */
  int stat_errno;		/* errno value set by stat() */
  struct stat info;		/* info structure from stat() */

  struct Dir_Item *sort;
  struct Dir_Item *next;
} Dir_Item;

typedef struct Dir_List
{
  Dir_Item *head;
  Dir_Item *tail;
} Dir_List;

/********** Global Routines Defined **********/


/********** Global Variables Defined **********/

extern uid_t Whoami;
extern Boole expand_symlink;

#endif /*ELS__ELS_H*/
