/******************************************************************************
  format.h -- Ubiquitous formats for ELS
  
  Author: Mark Baranowski (markb@elen.utah.edu)

  Last significant change: May 23, 2000
  
  These functions are provided "as is" in the hopes that they might serve some
  higher purpose.  If you want these functions to serve some lower purpose,
  then that too is all right.  So as to keep these hopes alive you may
  freely distribute these functions so long as this header remains intact.
  You may also freely distribute modified versions of these functions so long
  as you indicate that such versions are modified and so long as you
  provide access to the unmodified original copy.
  
  Note: The most recent version of these functions may be obtained from
  ftp://auriga.elen.utah.edu/pub/markb/els.tar.Z

  ****************************************************************************/

#ifndef ELS__FORMAT_H
#define ELS__FORMAT_H

/* Maximum width allowed in %nX specification: */
#define F_MAX_WIDTH  50

/*#define Wformat*/
#ifdef Wformat
/* Since gcc's -Wformat option can only detect printf format problems when the
   format is completely known at compile-time, the following macros should
   occasionally be enabled whenever trying to find format problems (this
   will prevent zero_pad from working, however): */
#define F_d        "%*d"
#define F_0d       "%0*d"
#define F_ld       "%*ld"
#define F_0ld      "%0*ld"
#define F_lld      "%*lld"
#define F_0lld     "%0*lld"
#define F_u        "%*u"
#define F_0u       "%0*u"
#define F_lu       "%*lu"
#define F_0lu      "%0*lu"
#define F_llu      "%*llu"
#define F_0llu     "%0*llu"
#define F_D(z,w)   F_d,w
#define F_LD(z,w)  F_ld,w
#define F_LLD(z,w) F_lld,w
#define F_U(z,w)   F_u,w
#define F_LU(z,w)  F_lu,w
#define F_LLU(z,w) F_llu,w
#else
/* The following macros allow for possible zero padding in conjunction with
   dynamic widths (gcc's -Wformat option will not detect format problems,
   however): */
const char *F_d    = "%*d";
const char *F_0d   = "%0*d";
const char *F_ld   = "%*ld";
const char *F_0ld  = "%0*ld";
const char *F_lld  = "%*lld";
const char *F_0lld = "%0*lld";
const char *F_u    = "%*u";
const char *F_0u   = "%0*u";
const char *F_lu   = "%*lu";
const char *F_0lu  = "%0*lu";
const char *F_llu  = "%*llu";
const char *F_0llu = "%0*llu";
#define F_D(z,w)   (z ? F_0d   : F_d),w
#define F_LD(z,w)  (z ? F_0ld  : F_ld),w
#define F_LLD(z,w) (z ? F_0lld : F_lld),w
#define F_U(z,w)   (z ? F_0u   : F_u),w
#define F_LU(z,w)  (z ? F_0lu  : F_lu),w
#define F_LLU(z,w) (z ? F_0llu : F_llu),w
#endif


/*---------------------------------------------------------------------------*/
#if defined(OSF1) || defined(HPUX)
/* time_t is NOT long under OSF1/DEC_ALPHA and HPUX 10.20: */
# define F_time_t(z,w)  F_U(z,w)
#else
# define F_time_t(z,w)  F_LU(z,w)
#endif

/*---------------------------------------------------------------------------*/
#ifdef HAVE_STAT64

/* Defaults (based on SunOS5.7/gcc2.8.1): */
#define F_st_ino(z,w)    F_LLU(z,w)
#define F_st_size(z,w)   F_LLD(z,w)
#define F_st_nlink(z,w)  F_LD(z,w)
#define F_st_blocks(z,w) F_LLD(z,w)

/* Exceptions: */
#if defined(HPUX)
/* HPUX 10.20's LARGEFILES use small st_ino: */
#undef  F_st_ino
#define F_st_ino(z,w)    F_U(z,w)
#undef  F_st_nlink
#define F_st_nlink(z,w)  F_D(z,w)
#endif

/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
#else

/* Defaults (based on SunOS5.5.1/gcc2.8.1): */
#define F_st_ino(z,w)    F_LD(z,w)
#define F_st_size(z,w)   F_LD(z,w)
#define F_st_nlink(z,w)  F_LD(z,w)
#define F_st_blocks(z,w) F_LD(z,w)

/* Exceptions: */
#if defined(LINUX) || SUNOS==4
/* Linux2.2.12, SunOS4.1.3: */
#undef  F_st_nlink
#define F_st_nlink(z,w)  F_D(z,w)
#endif

#if defined(OSF1)
/* OSF1/DEC Unix4.0: */
#undef  F_st_ino
#define F_st_ino(z,w)    F_D(z,w)
#undef  F_st_nlink
#define F_st_nlink(z,w)  F_D(z,w)
#endif

#if defined(FREEBSD)
/* FreeBSD 3.4-RELEASE (w/off_t == int64): */
#undef  F_st_ino
#define F_st_ino(z,w)    F_U(z,w)
#undef  F_st_size
#define F_st_size(z,w)   F_LLD(z,w)
#undef  F_st_nlink
#define F_st_nlink(z,w)  F_U(z,w)
#endif

#endif
/*---------------------------------------------------------------------------*/

#endif /*ELS__FORMAT_H*/
