/******************************************************************************
  sysdefs.h -- System defines for ELS
  
  Author: Mark Baranowski (markb@elen.utah.edu)

  Last significant change: October 12, 2000
  
  These functions are provided "as is" in the hopes that they might serve some
  higher purpose.  If you want these functions to serve some lower purpose,
  then that too is all right.  So as to keep these hopes alive you may
  freely distribute these functions so long as this header remains intact.
  You may also freely distribute modified versions of these functions so long
  as you indicate that such versions are modified and so long as you
  provide access to the unmodified original copy.
  
  Note: The most recent version of these functions may be obtained from
  ftp://auriga.elen.utah.edu/pub/markb/els.tar.Z

  ****************************************************************************/

#ifndef ELS__SYSDEFS_H
#define ELS__SYSDEFS_H

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* All versions of HPUX should have this defined: */
#if defined(HPUX)
#  ifndef _HPUX_SOURCE
#    define _HPUX_SOURCE
#  endif
#endif

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* The define HAVE_TIME_R is helpful but not mandatory.  For example, there
   may be other untested OS versions not included in the following list that
   may also support localtime_r(), gmtime_r(), asctime_r(), and ctime_r().  It
   may also be possible that earlier versions of an OS (e.g.  HPUX9) support
   *time_r(), but until proven otherwise it is better to assume that *time_r()
   functions are missing. */

/* The following OSes are known to support *time_r():
   SunOS5, HPUX10, OSF1/DigitalUNIX4.0 */
#if SUNOS>=5 || HPUX>=10 || defined(OSF1)
#  define HAVE_TIME_R
#  define _REENTRANT
/* Note: SunOS5.4, HPUX10, OSF1 require that _REENTRANT be defined,
   while SunOS5.5+ requires either of _REENTRANT or __EXTENSIONS__ */
#endif

/* The following OSes are known to also support *time_r():
   Linux 2.2.12, FreeBSD 3.2, FreeBSD 4.0 */
#if defined(LINUX) || defined(FREEBSD)
#  define HAVE_TIME_R
#endif

/* The following OSes are known to NOT support *time_r():
   SunOS4 */
#if SUNOS==4
#  undef HAVE_TIME_R
#endif

#if defined(LINUX) || defined(FREEBSD) || defined(OSF1) || defined(IRIX)
/* The following OSes use 2 args for asctime_r() and ctime_r():
   Linux 2.2.12, FreeBSD 3.2, FreeBSD 4.0, OSF1, IRIX 6.x */
#  define USE_POSIX_TIME_R
#else
/* The following OSes use 3 args for asctime_r() and ctime_r():
   SunOS5, HPUX10 */
#  undef USE_POSIX_TIME_R
#endif

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
#if defined(HAVE_STAT64)

# if defined(SUNOS)
#   define __EXTENSIONS__
#   define LARGEFILE_SOURCE
#   define LARGEFILE64_SOURCE
# endif

# if defined(HPUX)
#ifndef  __STDC_EXT__
#   define __STDC_EXT__
#endif
#   define _LARGEFILE64_SOURCE
# endif

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
#else /* !defined(HAVE_STAT64) */

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
#endif

#endif /*ELS__SYSDEFS_H*/
